'/*-------------------------------------------------------------------- *
'*                                                                      *
'*   3333   CCCC      CCCC  OOOO  N     N  CCCC  EEEEE  PPPP  TTTTTTT   *
'*       3 C         C     O    O NN    N C      E      P   P    T      *
'*       3 C         C     O    O N N   N C      E      P   P    T      *
'*   3333  C         C     O    O N  N  N C      EEEE   PPPP     T      *
'*       3 C         C     O    O N   N N C      E      P        T      *
'*       3 C         C     O    O N    NN C      E      P        T      *
'*   3333   CCCC      CCCC  OOOO  N     N  CCCC  EEEEE  P        T      *
'*                                                                      *
'*     UNITE D'INTERFACE POUR DLL/Win32 Module TC/USB-16IO              *
'*                                                                      *
'*  Wrapper VB.NET pour utilsation du module TCUSB16IO                  *
'*  Microsoft Visual Basic 2010 Express                                 *
'*                                                                      *    
'*                                                                      *
'* (c)2014 3C CONCEPT S.A.S                							    *	
'*  V1.00 : DB : 03/11/2014 :creation version VB.NET					*
'*  V1.01 : JT : 05/05/2017 :ajout fonctions latch					    *
'* -------------------------------------------------------------------- *
'*/

Imports System.Runtime.InteropServices
Module TCUSB16IO
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Refresh(NModule As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_OpenN(NModule As Integer, ByRef NumSerie As UInt32) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_OpenN_InitOutput(NModule As Integer, ByRef NumSerie As UInt32, Data As Byte) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Close(NModule As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Input(NModule As Integer, ByRef Data As UInt32) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Output(NModule As Integer, Data As Byte) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_BitInput(NModule As Integer, Entree As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Sub TCUSB16IO_BitOutput(NModule As Integer, Sortie As Integer, etat As Integer)
    End Sub
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_BitReadBack(NModule As Integer, Sortie As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Counter(NModule As Integer, Entree As Integer, ByRef Data As Byte) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Config(NModule As Integer, Data As Byte) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Pos(NModule As Integer, ByRef Data As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_ResetPos(NModule As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_ConfigLatch(NModule As Integer, Data As Byte) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Latch(NModule As Integer, Latch as Byte, ByRef Data As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_WdgRun(NModule As Integer) As Integer
    End Function
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Sub TCUSB16IO_WdgStop(NModule As Integer)
    End Sub
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Sub TCUSB16IO_WdgRearm(NModule As Integer)
    End Sub
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Sub TCUSB16IO_ResetPort(NModule As Integer)
    End Sub
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Sub TCUSB16IO_CyclePort(NModule As Integer)
    End Sub
    <DllImport("TCUSB16IO.dll", CharSet:=CharSet.Ansi, CallingConvention:=CallingConvention.StdCall, SetLastError:=True, ExactSpelling:=True)> _
    Public Function TCUSB16IO_Version(NModule As Integer, ByRef Data1 As Byte, ByRef Data2 As Byte) As Integer
    End Function

End Module
